==> adestis-netbox-plugin-account-management-1.7.9.tar.gz: adestis-netbox-plugin-account-management-1.7.9/adestis_netbox_plugin_account_management/forms/login_credentials.py <==
import json
from django import forms
from django.core.exceptions import ValidationError
from netbox.forms import NetBoxModelForm, NetBoxModelFilterSetForm, NetBoxModelBulkEditForm, NetBoxModelImportForm
from utilities.forms.fields import CommentField, DynamicModelChoiceField, DynamicModelMultipleChoiceField, CSVChoiceField, CSVModelChoiceField, TagFilterField
from utilities.forms.widgets import DatePicker
from adestis_netbox_plugin_account_management.models.login_credentials import LoginCredentials, LoginCredentialsStatusChoices
from adestis_netbox_plugin_account_management.models.system import System, SystemStatusChoices
from tenancy.models import Contact
from django.utils.translation import gettext as _

__all__ = (
    'LoginCredentialsForm',
    'LoginCredentialsFilterForm',
    'LoginCredentialsBulkEditForm',
    'LoginCredentialsCSVForm'
)


class LoginCredentialsForm(NetBoxModelForm):
    comments = CommentField()

    contact = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        required=True,
    )

    system = DynamicModelChoiceField(
        queryset=System.objects.all(),
        required=True,
    )

    fieldsets = (
        (None, ('logon_name', 'contact', 'system', 'login_credentials_status', 'tags')),
        ('Validity', ('valid_from', 'valid_to')),
    )  

    class Meta:
        model = LoginCredentials
        fields = ['logon_name', 'contact', 'system', 'valid_from', 'valid_to',
                  'login_credentials_status', 'comments', 'tags']
        widgets = {
            'valid_from': DatePicker(),
            'valid_to': DatePicker()
        }
        help_texts = {
            'logon_name': "Logon name",
        }

    def clean(self):
        super().clean()

        fieldsToValidate = [
            field for field in (
                'valid_from', 'valid_to'
            ) if self.cleaned_data[field]
        ]

        shouldValidate = len(fieldsToValidate)==2

        if shouldValidate == True:
            valid_from_data = self.cleaned_data["valid_from"]
            valid_to_data = self.cleaned_data["valid_to"]
            # Only do something if both fields are valid so far.
            if valid_to_data < valid_from_data:
                raise ValidationError(
                    "Invalid date range! Field 'Valid to' must be older than field 'Valid from'"
                )


class LoginCredentialsBulkEditForm(NetBoxModelBulkEditForm):
    pk = forms.ModelMultipleChoiceField(
        queryset=LoginCredentials.objects.all(),
        widget=forms.MultipleHiddenInput
    )
    
    system = DynamicModelChoiceField(
        queryset=System.objects.all(),
        required=False
    )
    
    contact = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        required=False
    )
    
    logon_name = forms.CharField(
        max_length=254,
        required=False
    )
    
    valid_from = forms.DateField(
        required=False
    )

    valid_to = forms.DateField(
        required=False
    )
    
    login_credentials_status = forms.ChoiceField(
        required=False,
        choices=LoginCredentialsStatusChoices,
    )

    model = LoginCredentials
    
    fieldsets = (
        (None, ('logon_name', 'contact', 'system', 'login_credentials_status')),
        ('Validity', ('valid_from', 'valid_to')),
    )  
    
    nullable_fields = [
       'valid_from', 'valid_to', 'add_tags', 'remove_tags'
    ]

class LoginCredentialsFilterForm(NetBoxModelFilterSetForm):
    model = LoginCredentials
    
    fieldsets = (
        (None, ('q', 'index', 'tag', 'contact_id', 'system', 'login_credentials_status')),
    )  

    index = forms.IntegerField(
        required=False
    )

    contact_id = DynamicModelMultipleChoiceField(
        queryset=Contact.objects.all(),
        required=False,
        null_option='None',
        label=_('Contact')
    )

    system = forms.ModelMultipleChoiceField(
        queryset=System.objects.all(),
        required=False
    )

    login_credentials_status = forms.MultipleChoiceField(
        choices = LoginCredentialsStatusChoices,
        required=False
    )
    
    tag = TagFilterField(model)
    
    
class LoginCredentialsCSVForm(NetBoxModelImportForm):
    
    system = CSVModelChoiceField(
        queryset=System.objects.all(),
        required=True,
        to_field_name='system_url',
        help_text='System URL'
    )
    
    contact = CSVModelChoiceField(
        queryset=Contact.objects.all(),
        required=True,
        to_field_name='email',
        help_text='Email address of the contact'
    )
    
    login_credentials_status = CSVChoiceField(
        choices=LoginCredentialsStatusChoices,
        help_text=_('Status'),
        required=True,
    )
        
    class Meta:
        model = LoginCredentials
        fields = ['system', 'contact', 'login_credentials_status', 'logon_name']
        default_return_url = 'plugins:adestis_netbox_plugin_account_management:logincredentials_list'

==> adestis-netbox-plugin-account-management-1.9.0.tar.gz: adestis-netbox-plugin-account-management-1.9.0/adestis_netbox_plugin_account_management/forms/login_credentials.py <==
from django import forms
from django.core.exceptions import ValidationError
from adestis_netbox_plugin_account_management.models.ssh_key import SshKey
from netbox.forms import NetBoxModelForm, NetBoxModelFilterSetForm, NetBoxModelBulkEditForm, NetBoxModelImportForm
from utilities.forms.fields import CommentField, DynamicModelChoiceField, DynamicModelMultipleChoiceField, CSVModelMultipleChoiceField, CSVChoiceField, CSVModelChoiceField, TagFilterField
from utilities.forms.widgets import DatePicker
from adestis_netbox_plugin_account_management.models.login_credentials import LoginCredentials, LoginCredentialsStatusChoices
from adestis_netbox_plugin_account_management.models.system import System, SystemStatusChoices
from tenancy.models import Contact
from django.utils.translation import gettext_lazy as _
from utilities.forms.rendering import FieldSet
from dcim.models import Device, DeviceRole, Platform, Rack, Region, Site, SiteGroup
from extras.models import Tag

__all__ = (
    'LoginCredentialsForm',
    'LoginCredentialsFilterForm',
    'LoginCredentialsBulkEditForm',
    'LoginCredentialsCSVForm',
    'LoginCredentialsAssignSshKeyForm',
    'LoginCredentialWithSelectedSshKeyForm'
)

class LoginCredentialsForm(NetBoxModelForm):
    comments = CommentField()

    contact = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        required=True,
    )

    system = DynamicModelChoiceField(
        queryset=System.objects.all(),
        required=True,
    )

    ssh_keys = DynamicModelMultipleChoiceField(
        queryset=SshKey.objects.all(),
        label=_('SSH Keys'),
        required=False
    )

    fieldsets = (
        (None, ('logon_name', 'contact', 'ssh_keys',
         'system', 'login_credentials_status', 'tags')),
        ('Validity', ('valid_from', 'valid_to')),
    )

    class Meta:
        model = LoginCredentials
        fields = ['logon_name', 'contact', 'system', 'valid_from', 'valid_to',
                  'login_credentials_status', 'comments', 'tags']
        widgets = {
            'valid_from': DatePicker(),
            'valid_to': DatePicker()
        }
        help_texts = {
            'logon_name': "Logon name",
        }

    def clean(self):
        super().clean()

        fieldsToValidate = [
            field for field in (
                'valid_from', 'valid_to'
            ) if self.cleaned_data[field]
        ]

        shouldValidate = len(fieldsToValidate) == 2

        if shouldValidate == True:
            valid_from_data = self.cleaned_data["valid_from"]
            valid_to_data = self.cleaned_data["valid_to"]
            # Only do something if both fields are valid so far.
            if valid_to_data < valid_from_data:
                raise ValidationError(
                    "Invalid date range! Field 'Valid to' must be older than field 'Valid from'"
                )


class LoginCredentialsBulkEditForm(NetBoxModelBulkEditForm):
    pk = forms.ModelMultipleChoiceField(
        queryset=LoginCredentials.objects.all(),
        widget=forms.MultipleHiddenInput
    )

    system = DynamicModelChoiceField(
        queryset=System.objects.all(),
        required=False
    )

    contact = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        required=False
    )

    logon_name = forms.CharField(
        max_length=254,
        required=False
    )

    valid_from = forms.DateField(
        required=False
    )

    valid_to = forms.DateField(
        required=False
    )

    login_credentials_status = forms.ChoiceField(
        required=False,
        choices=LoginCredentialsStatusChoices,
    )

    ssh_keys = DynamicModelMultipleChoiceField(
        queryset=SshKey.objects.all(),
        label=_('SSH Keys'),
        to_field_name='key_comment',
        null_option='None',
        required=False
    )

    model = LoginCredentials

    fieldsets = (
        (None, ('logon_name', 'contact', 'system',
         'ssh_keys', 'login_credentials_status')),
        ('Validity', ('valid_from', 'valid_to')),
    )

    nullable_fields = [
        'valid_from', 'valid_to', 'add_tags', 'remove_tags'
    ]


class LoginCredentialsFilterForm(NetBoxModelFilterSetForm):
    model = LoginCredentials

    fieldsets = (
        (None, ('q', 'index', 'tag', 'contact', 'ssh_keys',
         'system', 'login_credentials_status')),
    )

    index = forms.IntegerField(
        required=False
    )

    contact = DynamicModelMultipleChoiceField(
        queryset=Contact.objects.all(),
        required=False,
        null_option='None',
        to_field_name='name',
        label=_('Contact')
    )

    ssh_keys = DynamicModelMultipleChoiceField(
        queryset=SshKey.objects.all(),
        label=_('SSH Keys'),
        to_field_name='key_comment',
        null_option='None',
        required=False
    )

    system = forms.ModelMultipleChoiceField(
        queryset=System.objects.all(),
        required=False
    )

    login_credentials_status = forms.MultipleChoiceField(
        choices=LoginCredentialsStatusChoices,
        required=False
    )

    tag = TagFilterField(model)


class LoginCredentialsCSVForm(NetBoxModelImportForm):

    system = CSVModelChoiceField(
        queryset=System.objects.all(),
        required=True,
        to_field_name='system_url',
        help_text='System URL'
    )

    contact = CSVModelChoiceField(
        queryset=Contact.objects.all(),
        required=True,
        to_field_name='email',
        help_text='Email address of the contact'
    )

    login_credentials_status = CSVChoiceField(
        choices=LoginCredentialsStatusChoices,
        help_text=_('Status'),
        required=True,
    )

    ssh_keys = CSVModelMultipleChoiceField(
        label=_('SSH Keys'),
        queryset=SshKey.objects.all(),
        required=False,
        to_field_name='key_comment',
        help_text=_('SSH Keys')
    )

    class Meta:
        model = LoginCredentials
        fields = ['system', 'contact', 'ssh_keys',
                  'login_credentials_status', 'logon_name']
        default_return_url = 'plugins:adestis_netbox_plugin_account_management:logincredentials_list'


class LoginCredentialsAssignSshKeyForm(forms.Form):
    
    sshkeys = DynamicModelMultipleChoiceField(
        label=_('SSH Keys'),
        queryset=SshKey.objects.all()
    )

    class Meta:
        fields = [
            'sshkeys',
        ]

    def __init__(self, loginCredentials,*args, **kwargs):

        self.loginCredentials = loginCredentials

        super().__init__(*args, **kwargs)

        self.fields['sshkeys'].choices = []


class LoginCredentialWithSelectedSshKeyForm(forms.Form):
    
    valid_from = forms.DateField(
        required=False,
        widget=DatePicker
    )

    valid_to = forms.DateField(
        required=False,
        widget=DatePicker
    )

    sshkeys = DynamicModelMultipleChoiceField(
        label=_('SSH Keys'),
        queryset=SshKey.objects.all(),
        disabled=True
    )

    logon_name = forms.CharField(
        max_length=254,
        required=True,
        label=_('Logon name')
    )

    comments = CommentField()

    contact = DynamicModelChoiceField(
        queryset=Contact.objects.all(),
        required=True,
        disabled=True
    )

    system = DynamicModelChoiceField(
        queryset=System.objects.all(),
        required=True,
    )
 
    login_credentials_status = forms.ChoiceField(
        label=_('Status'),
        choices=LoginCredentialsStatusChoices,
        required=True,
    )    

    tags = DynamicModelMultipleChoiceField(
        label=_('Tags'),
        queryset=Tag.objects.all(),
        required=False
    )    

    fieldsets = (
        (None, ('logon_name', 'contact', 'ssh_keys',
         'system', 'login_credentials_status', 'tags')),
        ('Validity', ('valid_from', 'valid_to')),
    )

    class Meta:
        fields = [
            'sshkeys', 'logon_name', 'system', 'contact', 'login_credentials_status', 'valid_from', 'valid_to', 'tags'
        ]
        help_texts = {
            'logon_name': "Logon name",
        }

    def __init__(self, sshkey,*args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['sshkeys'].initial = [sshkey]
        self.fields['contact'].initial = sshkey.contact

    def clean(self):
        super().clean()

        fieldsToValidate = [
            field for field in (
                'valid_from', 'valid_to'
            ) if self.cleaned_data[field]
        ]

        shouldValidate = len(fieldsToValidate) == 2

        if shouldValidate == True:
            valid_from_data = self.cleaned_data["valid_from"]
            valid_to_data = self.cleaned_data["valid_to"]
            # Only do something if both fields are valid so far.
            if valid_to_data < valid_from_data:
                raise ValidationError(
                    "Invalid date range! Field 'Valid to' must be older than field 'Valid from'"
                )
